==> protected_submissions-8.x-1.4.tar.gz: protected_submissions/src/Form/ProtectedSubmissionsForm.php <==
<?php

namespace Drupal\protected_submissions\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * ProtectedSubmissionsForm class.
 */
class ProtectedSubmissionsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'protected_submissions_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Form constructor.
    $form = parent::buildForm($form, $form_state);
    // Default settings.
    $config = $this->config('protected_submissions.settings');

    $language_scripts  = array(
      'Arabic' => 'Arabic',
      'Armenian' => 'Armenian',
      'Avestan' => 'Avestan',
      'Balinese' => 'Balinese',
      'Bamum' => 'Bamum',
      'Batak' => 'Batak',
      'Bengali' => 'Bengali',
      'Bopomofo' => 'Bopomofo',
      'Brahmi' => 'Brahmi',
      'Buginese' => 'Buginese',
      'Buhid' => 'Buhid',
      'Canadian Aboriginal' => 'Canadian Aboriginal',
      'Carian' => 'Carian',
      'Chakma' => 'Chakma',
      'Cham' => 'Cham',
      'Cherokee' => 'Cherokee',
      'CJK' => 'CJK',
      'Coptic' => 'Coptic',
      'Cuneiform' => 'Cuneiform',
      'Cypriot' => 'Cypriot',
      'Cyrillic' => 'Cyrillic',
      'Deseret' => 'Deseret',
      'Devanagari' => 'Devanagari',
      'Egyptian Hieroglyphs' => 'Egyptian Hieroglyphs',
      'Ethiopic' => 'Ethiopic',
      'Georgian' => 'Georgian',
      'Glagolitic' => 'Glagolitic',
      'Gothic' => 'Gothic',
      'Greek' => 'Greek',
      'Gujarati' => 'Gujarati',
      'Gurmukhi' => 'Gurmukhi',
      'Hangul' => 'Hangul',
      'Hanunoo' => 'Hanunoo',
      'Hebrew' => 'Hebrew',
      'Hiragana' => 'Hiragana',
      'Imperial Aramaic' => 'Imperial Aramaic',
      'Inscriptional Pahlavi' => 'Inscriptional Pahlavi',
      'Inscriptional Parthian' => 'Inscriptional Parthian',
      'Javanese' => 'Javanese',
      'Kaithi' => 'Kaithi',
      'Kanbun' => 'Kanbun',
      'Kangxi' => 'Kangxi',
      'Kannada' => 'Kannada',
      'Katakana' => 'Katakana',
      'Kayah Li' => 'Kayah Li',
      'Kharoshthi' => 'Kharoshthi',
      'Khmer' => 'Khmer',
      'Lao' => 'Lao',
      'Latin' => 'Latin',
      'Lepcha' => 'Lepcha',
      'Limbu' => 'Limbu',
      'Lisu' => 'Lisu',
      'Lycian' => 'Lycian',
      'Lydian' => 'Lydian',
      'Malayalam' => 'Malayalam',
      'Mandaic' => 'Mandaic',
      'Meetei Mayek' => 'Meetei Mayek',
      'Meroitic Cursive' => 'Meroitic Cursive',
      'Meroitic Hieroglyphs' => 'Meroitic Hieroglyphs',
      'Miao' => 'Miao',
      'Mongolian' => 'Mongolian',
      'Myanmar' => 'Myanmar',
      'New Tai Lue' => 'New Tai Lue',
      'Nko' => 'Nko',
      'Ogham' => 'Ogham',
      'Ol Chiki' => 'Ol Chiki',
      'Old Italic' => 'Old Italic',
      'Old Persian' => 'Old Persian',
      'Old South Arabian' => 'Old South Arabian',
      'Old Turkic' => 'Old Turkic',
      'Oriya' => 'Oriya' ,
      'Osmanya' => 'Osmanya',
      'Phags Pa' => 'Phags Pa',
      'Phoenician' => 'Phoenician',
      'Rejang' => 'Rejang',
      'Runic' => 'Runic',
      'Samaritan' => 'Samaritan',
      'Saurashtra' => 'Saurashtra',
      'Sharada' => 'Sharada',
      'Shavian' => 'Shavian',
      'Sinhala' => 'Sinhala',
      'Sora Sompeng' => 'Sora Sompeng',
      'Sundanese' => 'Sundanese',
      'Syloti Nagri' => 'Syloti Nagri',
      'Syriac' => 'Syriac',
      'Tagalog' => 'Tagalog',
      'Tagbanwa' => 'Tagbanwa',
      'Tai Le' => 'Tai Le',
      'Tai Tham' => 'Tai Tham',
      'Tai Viet' => 'Tai Viet',
      'Takri' => 'Takri',
      'Tamil' => 'Tamil',
      'Telugu' => 'Telugu',
      'Thaana' => 'Thaana',
      'Thai' => 'Thai',
      'Tibetan' => 'Tibetan',
      'Tifinagh' => 'Tifinagh',
      'Ugaritic' => 'Ugaritic',
      'Vai' => 'Vai',
      'Yi' => 'Yi' ,
      'Yijing' => 'Yijing',
    );

    $form['allowed_scripts'] = array(
      '#type' => 'checkboxes',
      '#options' => $language_scripts,
      '#default_value' =>  $config->get('protected_submissions.allowed_scripts'),
      '#title' => t('Allowed language scripts'),
      '#required' => TRUE,
      '#description' => t('Select language scripts allowed for submission.'),
    );

    $form['check_quantity'] = array(
      '#type' => 'textfield',
      '#default_value' => $config->get('protected_submissions.check_quantity'),
      '#title' => t('Number of characters to validate'),
      '#size' => 5,
      '#required' => TRUE,
      '#description' => t('Spam texts can be constructed using mixed characters from multiple languages.
      Checking each character would cause performance overhead, so we validate only randomly selected characters.
      Indicate how many characters from submitted text should be validated for allowed language scripts.'),
    );
    // Page title field.
    $form['reject_message'] = array(
      '#type' => 'textarea',
      '#title' => $this->t('Reject message:'),
      '#default_value' => $config->get('protected_submissions.reject_message'),
      '#required' => TRUE,
      '#description' => $this->t('Enter a message to display when submission of undesired pattern is attempted.'),
    );
    // Source text field.
    $form['reject_patterns'] = array(
      '#type' => 'textarea',
      '#title' => $this->t('Reject patterns:'),
      '#default_value' => $config->get('protected_submissions.reject_patterns'),
      '#required' => TRUE,
      '#description' => $this->t('Enter words or patterns to reject, separating them with commas or new lines.'),
    );
    // Give users option to enable/disable logging if Database Logging is on.
    $moduleHandler = \Drupal::service('module_handler');
    if ($moduleHandler->moduleExists('dblog')) {
      $form['log_rejected'] = array(
        '#type' => 'checkbox',
        '#title' => $this->t('Log rejected messages?'),
        '#default_value' => $config->get('protected_submissions.log_rejected'),
        '#required' => FALSE,
        '#description' => $this->t('Registering every rejected submission could quickly flood your website\'s log. If you don\'t need to analyze rejected messages, then you might want to disable logging.'),
      );
    }

    $form['#attached']['library'][] = 'protected_submissions/protected_submissions';

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if (strlen($form_state->getValue('reject_message')) == 0) {
      $form_state->setErrorByName('user', t('You must enter a reject message to be displayed when an undesired pattern is detected on submission.'));
    }
    elseif (strlen($form_state->getValue('reject_patterns')) == 0) {
      $form_state->setErrorByName('user', t('You must enter the pattern(s) to trigger a submission rejection when matched.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $config = $this->config('protected_submissions.settings');
    $config->set('protected_submissions.allowed_scripts', $form_state->getValue('allowed_scripts'));
    $config->set('protected_submissions.check_quantity', $form_state->getValue('check_quantity'));
    $config->set('protected_submissions.reject_message', $form_state->getValue('reject_message'));
    $config->set('protected_submissions.reject_patterns', $form_state->getValue('reject_patterns'));
    $config->set('protected_submissions.log_rejected', $form_state->getValue('log_rejected'));
    $config->save();
    return parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'protected_submissions.settings',
    ];
  }

}

==> protected_submissions-8.x-1.5.tar.gz: protected_submissions/src/Form/ProtectedSubmissionsForm.php <==
<?php

namespace Drupal\protected_submissions\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * ProtectedSubmissionsForm class.
 */
class ProtectedSubmissionsForm extends ConfigFormBase {

  /**
   * Protected $moduleHandler.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('module_handler')
    );
  }

  /**
   * ProtectedSubmissionsForm constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $moduleHandler
   *   The moduler handler.
   */
  public function __construct(ConfigFactoryInterface $config_factory, ModuleHandlerInterface $moduleHandler) {
    parent::__construct($config_factory);
    $this->moduleHandler = $moduleHandler;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'protected_submissions_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Form constructor.
    $form = parent::buildForm($form, $form_state);
    // Default settings.
    $config = $this->config('protected_submissions.settings');

    $language_scripts = [
      'Arabic' => 'Arabic',
      'Armenian' => 'Armenian',
      'Avestan' => 'Avestan',
      'Balinese' => 'Balinese',
      'Bamum' => 'Bamum',
      'Batak' => 'Batak',
      'Bengali' => 'Bengali',
      'Bopomofo' => 'Bopomofo',
      'Brahmi' => 'Brahmi',
      'Buginese' => 'Buginese',
      'Buhid' => 'Buhid',
      'Canadian Aboriginal' => 'Canadian Aboriginal',
      'Carian' => 'Carian',
      'Chakma' => 'Chakma',
      'Cham' => 'Cham',
      'Cherokee' => 'Cherokee',
      'CJK' => 'CJK',
      'Coptic' => 'Coptic',
      'Cuneiform' => 'Cuneiform',
      'Cypriot' => 'Cypriot',
      'Cyrillic' => 'Cyrillic',
      'Deseret' => 'Deseret',
      'Devanagari' => 'Devanagari',
      'Egyptian Hieroglyphs' => 'Egyptian Hieroglyphs',
      'Ethiopic' => 'Ethiopic',
      'Georgian' => 'Georgian',
      'Glagolitic' => 'Glagolitic',
      'Gothic' => 'Gothic',
      'Greek' => 'Greek',
      'Gujarati' => 'Gujarati',
      'Gurmukhi' => 'Gurmukhi',
      'Hangul' => 'Hangul',
      'Hanunoo' => 'Hanunoo',
      'Hebrew' => 'Hebrew',
      'Hiragana' => 'Hiragana',
      'Imperial Aramaic' => 'Imperial Aramaic',
      'Inscriptional Pahlavi' => 'Inscriptional Pahlavi',
      'Inscriptional Parthian' => 'Inscriptional Parthian',
      'Javanese' => 'Javanese',
      'Kaithi' => 'Kaithi',
      'Kanbun' => 'Kanbun',
      'Kangxi' => 'Kangxi',
      'Kannada' => 'Kannada',
      'Katakana' => 'Katakana',
      'Kayah Li' => 'Kayah Li',
      'Kharoshthi' => 'Kharoshthi',
      'Khmer' => 'Khmer',
      'Lao' => 'Lao',
      'Latin' => 'Latin',
      'Lepcha' => 'Lepcha',
      'Limbu' => 'Limbu',
      'Lisu' => 'Lisu',
      'Lycian' => 'Lycian',
      'Lydian' => 'Lydian',
      'Malayalam' => 'Malayalam',
      'Mandaic' => 'Mandaic',
      'Meetei Mayek' => 'Meetei Mayek',
      'Meroitic Cursive' => 'Meroitic Cursive',
      'Meroitic Hieroglyphs' => 'Meroitic Hieroglyphs',
      'Miao' => 'Miao',
      'Mongolian' => 'Mongolian',
      'Myanmar' => 'Myanmar',
      'New Tai Lue' => 'New Tai Lue',
      'Nko' => 'Nko',
      'Ogham' => 'Ogham',
      'Ol Chiki' => 'Ol Chiki',
      'Old Italic' => 'Old Italic',
      'Old Persian' => 'Old Persian',
      'Old South Arabian' => 'Old South Arabian',
      'Old Turkic' => 'Old Turkic',
      'Oriya' => 'Oriya' ,
      'Osmanya' => 'Osmanya',
      'Phags Pa' => 'Phags Pa',
      'Phoenician' => 'Phoenician',
      'Rejang' => 'Rejang',
      'Runic' => 'Runic',
      'Samaritan' => 'Samaritan',
      'Saurashtra' => 'Saurashtra',
      'Sharada' => 'Sharada',
      'Shavian' => 'Shavian',
      'Sinhala' => 'Sinhala',
      'Sora Sompeng' => 'Sora Sompeng',
      'Sundanese' => 'Sundanese',
      'Syloti Nagri' => 'Syloti Nagri',
      'Syriac' => 'Syriac',
      'Tagalog' => 'Tagalog',
      'Tagbanwa' => 'Tagbanwa',
      'Tai Le' => 'Tai Le',
      'Tai Tham' => 'Tai Tham',
      'Tai Viet' => 'Tai Viet',
      'Takri' => 'Takri',
      'Tamil' => 'Tamil',
      'Telugu' => 'Telugu',
      'Thaana' => 'Thaana',
      'Thai' => 'Thai',
      'Tibetan' => 'Tibetan',
      'Tifinagh' => 'Tifinagh',
      'Ugaritic' => 'Ugaritic',
      'Vai' => 'Vai',
      'Yi' => 'Yi' ,
      'Yijing' => 'Yijing',
    ];

    $form['allowed_scripts'] = [
      '#type' => 'checkboxes',
      '#options' => $language_scripts,
      '#default_value' => $config->get('protected_submissions.allowed_scripts'),
      '#title' => $this->t('Allowed language scripts'),
      '#required' => TRUE,
      '#description' => $this->t('Select language scripts allowed for submission.'),
    ];

    $form['check_quantity'] = [
      '#type' => 'textfield',
      '#default_value' => $config->get('protected_submissions.check_quantity'),
      '#title' => $this->t('Number of characters to validate'),
      '#size' => 5,
      '#required' => TRUE,
      '#description' => $this->t('Spam texts can be constructed using mixed characters from multiple languages.
      Checking each character would cause performance overhead, so we validate only randomly selected characters.
      Indicate how many characters from submitted text should be validated for allowed language scripts.'),
    ];
    // Page title field.
    $form['reject_message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Reject message:'),
      '#default_value' => $config->get('protected_submissions.reject_message'),
      '#required' => TRUE,
      '#description' => $this->t('Enter a message to display when submission of undesired pattern is attempted.'),
    ];
    // Source text field.
    $form['reject_patterns'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Reject patterns:'),
      '#default_value' => $config->get('protected_submissions.reject_patterns'),
      '#required' => TRUE,
      '#description' => $this->t('Enter words or patterns to reject, separating them with commas or new lines.'),
    ];
    // Give users option to enable/disable logging if Database Logging is on.
    if ($this->moduleHandler->moduleExists('dblog')) {
      $form['log_rejected'] = [
        '#type' => 'checkbox',
        '#title' => $this->t('Log rejected submissions'),
        '#default_value' => $config->get('protected_submissions.log_rejected'),
        '#required' => FALSE,
        '#description' => $this->t('Checking on this option could potentially flood <a href="@log">the website\'s log</a>, so use this feature only if you need to analyze the rejected submissions.', ['@log' => '/admin/reports/dblog']),
      ];
    }

    $form['#attached']['library'][] = 'protected_submissions/protected_submissions';

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if (strlen($form_state->getValue('reject_message')) == 0) {
      $form_state->setErrorByName('user', $this->t('You must enter a reject message to be displayed when an undesired pattern is detected on submission.'));
    }
    elseif (strlen($form_state->getValue('reject_patterns')) == 0) {
      $form_state->setErrorByName('user', $this->t('You must enter the pattern(s) to trigger a submission rejection when matched.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $config = $this->config('protected_submissions.settings');
    $config->set('protected_submissions.allowed_scripts', $form_state->getValue('allowed_scripts'));
    $config->set('protected_submissions.check_quantity', $form_state->getValue('check_quantity'));
    $config->set('protected_submissions.reject_message', $form_state->getValue('reject_message'));
    $config->set('protected_submissions.reject_patterns', $form_state->getValue('reject_patterns'));
    $config->set('protected_submissions.log_rejected', $form_state->getValue('log_rejected'));
    $config->save();
    return parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'protected_submissions.settings',
    ];
  }

}
